# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dapr/dapr.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dapr/dapr.proto',
  package='dapr',
  syntax='proto3',
  serialized_options=_b('\n\007io.daprB\nDaprProtos'),
  serialized_pb=_b('\n\x0f\x64\x61pr/dapr.proto\x12\x04\x64\x61pr\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/duration.proto\"\xb9\x01\n\x1dInvokeServiceResponseEnvelope\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x43\n\x08metadata\x18\x02 \x03(\x0b\x32\x31.dapr.InvokeServiceResponseEnvelope.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x13\x44\x65leteStateEnvelope\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12#\n\x07options\x18\x03 \x01(\x0b\x32\x12.dapr.StateOptions\"9\n\x11SaveStateEnvelope\x12$\n\x08requests\x18\x01 \x03(\x0b\x32\x12.dapr.StateRequest\"4\n\x10GetStateEnvelope\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x13\n\x0b\x63onsistency\x18\x02 \x01(\t\"L\n\x18GetStateResponseEnvelope\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\"\xb7\x01\n\x15InvokeBindingEnvelope\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12;\n\x08metadata\x18\x03 \x03(\x0b\x32).dapr.InvokeBindingEnvelope.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc5\x01\n\x15InvokeServiceEnvelope\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\x12;\n\x08metadata\x18\x04 \x03(\x0b\x32).dapr.InvokeServiceEnvelope.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x14PublishEventEnvelope\x12\r\n\x05topic\x18\x01 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\xca\x01\n\x05State\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12+\n\x08metadata\x18\x04 \x03(\x0b\x32\x19.dapr.State.MetadataEntry\x12#\n\x07options\x18\x05 \x01(\x0b\x32\x12.dapr.StateOptions\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n\x0cStateOptions\x12\x13\n\x0b\x63oncurrency\x18\x01 \x01(\t\x12\x13\n\x0b\x63onsistency\x18\x02 \x01(\t\x12&\n\x0bretryPolicy\x18\x03 \x01(\x0b\x32\x11.dapr.RetryPolicy\"^\n\x0bRetryPolicy\x12\x11\n\tthreshold\x18\x01 \x01(\x05\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12+\n\x08interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xdf\x01\n\x0cStateRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x32\n\x08metadata\x18\x04 \x03(\x0b\x32 .dapr.StateRequest.MetadataEntry\x12*\n\x07options\x18\x05 \x01(\x0b\x32\x19.dapr.StateRequestOptions\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"l\n\x13StateRequestOptions\x12\x13\n\x0b\x63oncurrency\x18\x01 \x01(\t\x12\x13\n\x0b\x63onsistency\x18\x02 \x01(\t\x12+\n\x0bretryPolicy\x18\x03 \x01(\x0b\x32\x16.dapr.StateRetryPolicy\"c\n\x10StateRetryPolicy\x12\x11\n\tthreshold\x18\x01 \x01(\x05\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12+\n\x08interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration2\xb3\x03\n\x04\x44\x61pr\x12\x44\n\x0cPublishEvent\x12\x1a.dapr.PublishEventEnvelope\x1a\x16.google.protobuf.Empty\"\x00\x12S\n\rInvokeService\x12\x1b.dapr.InvokeServiceEnvelope\x1a#.dapr.InvokeServiceResponseEnvelope\"\x00\x12\x46\n\rInvokeBinding\x12\x1b.dapr.InvokeBindingEnvelope\x1a\x16.google.protobuf.Empty\"\x00\x12\x44\n\x08GetState\x12\x16.dapr.GetStateEnvelope\x1a\x1e.dapr.GetStateResponseEnvelope\"\x00\x12>\n\tSaveState\x12\x17.dapr.SaveStateEnvelope\x1a\x16.google.protobuf.Empty\"\x00\x12\x42\n\x0b\x44\x65leteState\x12\x19.dapr.DeleteStateEnvelope\x1a\x16.google.protobuf.Empty\"\x00\x42\x15\n\x07io.daprB\nDaprProtosb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])




_INVOKESERVICERESPONSEENVELOPE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='dapr.InvokeServiceResponseEnvelope.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.InvokeServiceResponseEnvelope.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.InvokeServiceResponseEnvelope.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=299,
)

_INVOKESERVICERESPONSEENVELOPE = _descriptor.Descriptor(
  name='InvokeServiceResponseEnvelope',
  full_name='dapr.InvokeServiceResponseEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='dapr.InvokeServiceResponseEnvelope.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='dapr.InvokeServiceResponseEnvelope.metadata', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INVOKESERVICERESPONSEENVELOPE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=299,
)


_DELETESTATEENVELOPE = _descriptor.Descriptor(
  name='DeleteStateEnvelope',
  full_name='dapr.DeleteStateEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.DeleteStateEnvelope.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='etag', full_name='dapr.DeleteStateEnvelope.etag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='dapr.DeleteStateEnvelope.options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=386,
)


_SAVESTATEENVELOPE = _descriptor.Descriptor(
  name='SaveStateEnvelope',
  full_name='dapr.SaveStateEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='dapr.SaveStateEnvelope.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=388,
  serialized_end=445,
)


_GETSTATEENVELOPE = _descriptor.Descriptor(
  name='GetStateEnvelope',
  full_name='dapr.GetStateEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.GetStateEnvelope.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consistency', full_name='dapr.GetStateEnvelope.consistency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=499,
)


_GETSTATERESPONSEENVELOPE = _descriptor.Descriptor(
  name='GetStateResponseEnvelope',
  full_name='dapr.GetStateResponseEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='dapr.GetStateResponseEnvelope.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='etag', full_name='dapr.GetStateResponseEnvelope.etag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=577,
)


_INVOKEBINDINGENVELOPE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='dapr.InvokeBindingEnvelope.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.InvokeBindingEnvelope.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.InvokeBindingEnvelope.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=299,
)

_INVOKEBINDINGENVELOPE = _descriptor.Descriptor(
  name='InvokeBindingEnvelope',
  full_name='dapr.InvokeBindingEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='dapr.InvokeBindingEnvelope.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='dapr.InvokeBindingEnvelope.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='dapr.InvokeBindingEnvelope.metadata', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INVOKEBINDINGENVELOPE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=763,
)


_INVOKESERVICEENVELOPE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='dapr.InvokeServiceEnvelope.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.InvokeServiceEnvelope.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.InvokeServiceEnvelope.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=299,
)

_INVOKESERVICEENVELOPE = _descriptor.Descriptor(
  name='InvokeServiceEnvelope',
  full_name='dapr.InvokeServiceEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dapr.InvokeServiceEnvelope.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='dapr.InvokeServiceEnvelope.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='dapr.InvokeServiceEnvelope.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='dapr.InvokeServiceEnvelope.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INVOKESERVICEENVELOPE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=963,
)


_PUBLISHEVENTENVELOPE = _descriptor.Descriptor(
  name='PublishEventEnvelope',
  full_name='dapr.PublishEventEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='dapr.PublishEventEnvelope.topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='dapr.PublishEventEnvelope.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1038,
)


_STATE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='dapr.State.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.State.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.State.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=299,
)

_STATE = _descriptor.Descriptor(
  name='State',
  full_name='dapr.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.State.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.State.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='etag', full_name='dapr.State.etag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='dapr.State.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='dapr.State.options', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STATE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1041,
  serialized_end=1243,
)


_STATEOPTIONS = _descriptor.Descriptor(
  name='StateOptions',
  full_name='dapr.StateOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='concurrency', full_name='dapr.StateOptions.concurrency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consistency', full_name='dapr.StateOptions.consistency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retryPolicy', full_name='dapr.StateOptions.retryPolicy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1245,
  serialized_end=1341,
)


_RETRYPOLICY = _descriptor.Descriptor(
  name='RetryPolicy',
  full_name='dapr.RetryPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='threshold', full_name='dapr.RetryPolicy.threshold', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='dapr.RetryPolicy.pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='dapr.RetryPolicy.interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1437,
)


_STATEREQUEST_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='dapr.StateRequest.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.StateRequest.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.StateRequest.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=299,
)

_STATEREQUEST = _descriptor.Descriptor(
  name='StateRequest',
  full_name='dapr.StateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.StateRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.StateRequest.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='etag', full_name='dapr.StateRequest.etag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='dapr.StateRequest.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='dapr.StateRequest.options', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STATEREQUEST_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1663,
)


_STATEREQUESTOPTIONS = _descriptor.Descriptor(
  name='StateRequestOptions',
  full_name='dapr.StateRequestOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='concurrency', full_name='dapr.StateRequestOptions.concurrency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consistency', full_name='dapr.StateRequestOptions.consistency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retryPolicy', full_name='dapr.StateRequestOptions.retryPolicy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1665,
  serialized_end=1773,
)


_STATERETRYPOLICY = _descriptor.Descriptor(
  name='StateRetryPolicy',
  full_name='dapr.StateRetryPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='threshold', full_name='dapr.StateRetryPolicy.threshold', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='dapr.StateRetryPolicy.pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='dapr.StateRetryPolicy.interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1775,
  serialized_end=1874,
)

_INVOKESERVICERESPONSEENVELOPE_METADATAENTRY.containing_type = _INVOKESERVICERESPONSEENVELOPE
_INVOKESERVICERESPONSEENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INVOKESERVICERESPONSEENVELOPE.fields_by_name['metadata'].message_type = _INVOKESERVICERESPONSEENVELOPE_METADATAENTRY
_DELETESTATEENVELOPE.fields_by_name['options'].message_type = _STATEOPTIONS
_SAVESTATEENVELOPE.fields_by_name['requests'].message_type = _STATEREQUEST
_GETSTATERESPONSEENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INVOKEBINDINGENVELOPE_METADATAENTRY.containing_type = _INVOKEBINDINGENVELOPE
_INVOKEBINDINGENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INVOKEBINDINGENVELOPE.fields_by_name['metadata'].message_type = _INVOKEBINDINGENVELOPE_METADATAENTRY
_INVOKESERVICEENVELOPE_METADATAENTRY.containing_type = _INVOKESERVICEENVELOPE
_INVOKESERVICEENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INVOKESERVICEENVELOPE.fields_by_name['metadata'].message_type = _INVOKESERVICEENVELOPE_METADATAENTRY
_PUBLISHEVENTENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STATE_METADATAENTRY.containing_type = _STATE
_STATE.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STATE.fields_by_name['metadata'].message_type = _STATE_METADATAENTRY
_STATE.fields_by_name['options'].message_type = _STATEOPTIONS
_STATEOPTIONS.fields_by_name['retryPolicy'].message_type = _RETRYPOLICY
_RETRYPOLICY.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_STATEREQUEST_METADATAENTRY.containing_type = _STATEREQUEST
_STATEREQUEST.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STATEREQUEST.fields_by_name['metadata'].message_type = _STATEREQUEST_METADATAENTRY
_STATEREQUEST.fields_by_name['options'].message_type = _STATEREQUESTOPTIONS
_STATEREQUESTOPTIONS.fields_by_name['retryPolicy'].message_type = _STATERETRYPOLICY
_STATERETRYPOLICY.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['InvokeServiceResponseEnvelope'] = _INVOKESERVICERESPONSEENVELOPE
DESCRIPTOR.message_types_by_name['DeleteStateEnvelope'] = _DELETESTATEENVELOPE
DESCRIPTOR.message_types_by_name['SaveStateEnvelope'] = _SAVESTATEENVELOPE
DESCRIPTOR.message_types_by_name['GetStateEnvelope'] = _GETSTATEENVELOPE
DESCRIPTOR.message_types_by_name['GetStateResponseEnvelope'] = _GETSTATERESPONSEENVELOPE
DESCRIPTOR.message_types_by_name['InvokeBindingEnvelope'] = _INVOKEBINDINGENVELOPE
DESCRIPTOR.message_types_by_name['InvokeServiceEnvelope'] = _INVOKESERVICEENVELOPE
DESCRIPTOR.message_types_by_name['PublishEventEnvelope'] = _PUBLISHEVENTENVELOPE
DESCRIPTOR.message_types_by_name['State'] = _STATE
DESCRIPTOR.message_types_by_name['StateOptions'] = _STATEOPTIONS
DESCRIPTOR.message_types_by_name['RetryPolicy'] = _RETRYPOLICY
DESCRIPTOR.message_types_by_name['StateRequest'] = _STATEREQUEST
DESCRIPTOR.message_types_by_name['StateRequestOptions'] = _STATEREQUESTOPTIONS
DESCRIPTOR.message_types_by_name['StateRetryPolicy'] = _STATERETRYPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InvokeServiceResponseEnvelope = _reflection.GeneratedProtocolMessageType('InvokeServiceResponseEnvelope', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVOKESERVICERESPONSEENVELOPE_METADATAENTRY,
    '__module__' : 'dapr.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.InvokeServiceResponseEnvelope.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _INVOKESERVICERESPONSEENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.InvokeServiceResponseEnvelope)
  })
_sym_db.RegisterMessage(InvokeServiceResponseEnvelope)
_sym_db.RegisterMessage(InvokeServiceResponseEnvelope.MetadataEntry)

DeleteStateEnvelope = _reflection.GeneratedProtocolMessageType('DeleteStateEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTATEENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.DeleteStateEnvelope)
  })
_sym_db.RegisterMessage(DeleteStateEnvelope)

SaveStateEnvelope = _reflection.GeneratedProtocolMessageType('SaveStateEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _SAVESTATEENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.SaveStateEnvelope)
  })
_sym_db.RegisterMessage(SaveStateEnvelope)

GetStateEnvelope = _reflection.GeneratedProtocolMessageType('GetStateEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATEENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.GetStateEnvelope)
  })
_sym_db.RegisterMessage(GetStateEnvelope)

GetStateResponseEnvelope = _reflection.GeneratedProtocolMessageType('GetStateResponseEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATERESPONSEENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.GetStateResponseEnvelope)
  })
_sym_db.RegisterMessage(GetStateResponseEnvelope)

InvokeBindingEnvelope = _reflection.GeneratedProtocolMessageType('InvokeBindingEnvelope', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVOKEBINDINGENVELOPE_METADATAENTRY,
    '__module__' : 'dapr.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.InvokeBindingEnvelope.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _INVOKEBINDINGENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.InvokeBindingEnvelope)
  })
_sym_db.RegisterMessage(InvokeBindingEnvelope)
_sym_db.RegisterMessage(InvokeBindingEnvelope.MetadataEntry)

InvokeServiceEnvelope = _reflection.GeneratedProtocolMessageType('InvokeServiceEnvelope', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVOKESERVICEENVELOPE_METADATAENTRY,
    '__module__' : 'dapr.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.InvokeServiceEnvelope.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _INVOKESERVICEENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.InvokeServiceEnvelope)
  })
_sym_db.RegisterMessage(InvokeServiceEnvelope)
_sym_db.RegisterMessage(InvokeServiceEnvelope.MetadataEntry)

PublishEventEnvelope = _reflection.GeneratedProtocolMessageType('PublishEventEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHEVENTENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.PublishEventEnvelope)
  })
_sym_db.RegisterMessage(PublishEventEnvelope)

State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATE_METADATAENTRY,
    '__module__' : 'dapr.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.State.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _STATE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.State)
  })
_sym_db.RegisterMessage(State)
_sym_db.RegisterMessage(State.MetadataEntry)

StateOptions = _reflection.GeneratedProtocolMessageType('StateOptions', (_message.Message,), {
  'DESCRIPTOR' : _STATEOPTIONS,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.StateOptions)
  })
_sym_db.RegisterMessage(StateOptions)

RetryPolicy = _reflection.GeneratedProtocolMessageType('RetryPolicy', (_message.Message,), {
  'DESCRIPTOR' : _RETRYPOLICY,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.RetryPolicy)
  })
_sym_db.RegisterMessage(RetryPolicy)

StateRequest = _reflection.GeneratedProtocolMessageType('StateRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATEREQUEST_METADATAENTRY,
    '__module__' : 'dapr.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.StateRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _STATEREQUEST,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.StateRequest)
  })
_sym_db.RegisterMessage(StateRequest)
_sym_db.RegisterMessage(StateRequest.MetadataEntry)

StateRequestOptions = _reflection.GeneratedProtocolMessageType('StateRequestOptions', (_message.Message,), {
  'DESCRIPTOR' : _STATEREQUESTOPTIONS,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.StateRequestOptions)
  })
_sym_db.RegisterMessage(StateRequestOptions)

StateRetryPolicy = _reflection.GeneratedProtocolMessageType('StateRetryPolicy', (_message.Message,), {
  'DESCRIPTOR' : _STATERETRYPOLICY,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.StateRetryPolicy)
  })
_sym_db.RegisterMessage(StateRetryPolicy)


DESCRIPTOR._options = None
_INVOKESERVICERESPONSEENVELOPE_METADATAENTRY._options = None
_INVOKEBINDINGENVELOPE_METADATAENTRY._options = None
_INVOKESERVICEENVELOPE_METADATAENTRY._options = None
_STATE_METADATAENTRY._options = None
_STATEREQUEST_METADATAENTRY._options = None

_DAPR = _descriptor.ServiceDescriptor(
  name='Dapr',
  full_name='dapr.Dapr',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1877,
  serialized_end=2312,
  methods=[
  _descriptor.MethodDescriptor(
    name='PublishEvent',
    full_name='dapr.Dapr.PublishEvent',
    index=0,
    containing_service=None,
    input_type=_PUBLISHEVENTENVELOPE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InvokeService',
    full_name='dapr.Dapr.InvokeService',
    index=1,
    containing_service=None,
    input_type=_INVOKESERVICEENVELOPE,
    output_type=_INVOKESERVICERESPONSEENVELOPE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InvokeBinding',
    full_name='dapr.Dapr.InvokeBinding',
    index=2,
    containing_service=None,
    input_type=_INVOKEBINDINGENVELOPE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetState',
    full_name='dapr.Dapr.GetState',
    index=3,
    containing_service=None,
    input_type=_GETSTATEENVELOPE,
    output_type=_GETSTATERESPONSEENVELOPE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SaveState',
    full_name='dapr.Dapr.SaveState',
    index=4,
    containing_service=None,
    input_type=_SAVESTATEENVELOPE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteState',
    full_name='dapr.Dapr.DeleteState',
    index=5,
    containing_service=None,
    input_type=_DELETESTATEENVELOPE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DAPR)

DESCRIPTOR.services_by_name['Dapr'] = _DAPR

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: daprclient/daprclient.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='daprclient/daprclient.proto',
  package='daprclient',
  syntax='proto3',
  serialized_options=_b('\n\007io.daprB\020DaprClientProtos'),
  serialized_pb=_b('\n\x1b\x64\x61prclient/daprclient.proto\x12\ndaprclient\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/duration.proto\"\x9f\x01\n\x12\x43loudEventEnvelope\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0bspecVersion\x18\x04 \x01(\t\x12\x17\n\x0f\x64\x61taContentType\x18\x05 \x01(\t\x12\r\n\x05topic\x18\x06 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x07 \x01(\x0b\x32\x14.google.protobuf.Any\"\xbb\x01\n\x14\x42indingEventEnvelope\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12@\n\x08metadata\x18\x03 \x03(\x0b\x32..daprclient.BindingEventEnvelope.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x01\n\x17\x42indingResponseEnvelope\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\n\n\x02to\x18\x02 \x03(\t\x12 \n\x05state\x18\x03 \x03(\x0b\x32\x11.daprclient.State\x12\x13\n\x0b\x63oncurrency\x18\x04 \x01(\t\"\xb1\x01\n\x0eInvokeEnvelope\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12:\n\x08metadata\x18\x03 \x03(\x0b\x32(.daprclient.InvokeEnvelope.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x1dGetTopicSubscriptionsEnvelope\x12\x0e\n\x06topics\x18\x01 \x03(\t\"4\n GetBindingsSubscriptionsEnvelope\x12\x10\n\x08\x62indings\x18\x01 \x03(\t\"\xd6\x01\n\x05State\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x31\n\x08metadata\x18\x04 \x03(\x0b\x32\x1f.daprclient.State.MetadataEntry\x12)\n\x07options\x18\x05 \x01(\x0b\x32\x18.daprclient.StateOptions\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n\x0cStateOptions\x12\x13\n\x0b\x63oncurrency\x18\x01 \x01(\t\x12\x13\n\x0b\x63onsistency\x18\x02 \x01(\t\x12,\n\x0bretryPolicy\x18\x03 \x01(\x0b\x32\x17.daprclient.RetryPolicy\"^\n\x0bRetryPolicy\x12\x11\n\tthreshold\x18\x01 \x01(\x05\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12+\n\x08interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration2\xb3\x03\n\nDaprClient\x12>\n\x08OnInvoke\x12\x1a.daprclient.InvokeEnvelope\x1a\x14.google.protobuf.Any\"\x00\x12\\\n\x15GetTopicSubscriptions\x12\x16.google.protobuf.Empty\x1a).daprclient.GetTopicSubscriptionsEnvelope\"\x00\x12\x62\n\x18GetBindingsSubscriptions\x12\x16.google.protobuf.Empty\x1a,.daprclient.GetBindingsSubscriptionsEnvelope\"\x00\x12Y\n\x0eOnBindingEvent\x12 .daprclient.BindingEventEnvelope\x1a#.daprclient.BindingResponseEnvelope\"\x00\x12H\n\x0cOnTopicEvent\x12\x1e.daprclient.CloudEventEnvelope\x1a\x16.google.protobuf.Empty\"\x00\x42\x1b\n\x07io.daprB\x10\x44\x61prClientProtosb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])




_CLOUDEVENTENVELOPE = _descriptor.Descriptor(
  name='CloudEventEnvelope',
  full_name='daprclient.CloudEventEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='daprclient.CloudEventEnvelope.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='daprclient.CloudEventEnvelope.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='daprclient.CloudEventEnvelope.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specVersion', full_name='daprclient.CloudEventEnvelope.specVersion', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataContentType', full_name='daprclient.CloudEventEnvelope.dataContentType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topic', full_name='daprclient.CloudEventEnvelope.topic', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='daprclient.CloudEventEnvelope.data', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=291,
)


_BINDINGEVENTENVELOPE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='daprclient.BindingEventEnvelope.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='daprclient.BindingEventEnvelope.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='daprclient.BindingEventEnvelope.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=481,
)

_BINDINGEVENTENVELOPE = _descriptor.Descriptor(
  name='BindingEventEnvelope',
  full_name='daprclient.BindingEventEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='daprclient.BindingEventEnvelope.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='daprclient.BindingEventEnvelope.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='daprclient.BindingEventEnvelope.metadata', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BINDINGEVENTENVELOPE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=481,
)


_BINDINGRESPONSEENVELOPE = _descriptor.Descriptor(
  name='BindingResponseEnvelope',
  full_name='daprclient.BindingResponseEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='daprclient.BindingResponseEnvelope.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to', full_name='daprclient.BindingResponseEnvelope.to', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='daprclient.BindingResponseEnvelope.state', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concurrency', full_name='daprclient.BindingResponseEnvelope.concurrency', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=484,
  serialized_end=612,
)


_INVOKEENVELOPE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='daprclient.InvokeEnvelope.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='daprclient.InvokeEnvelope.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='daprclient.InvokeEnvelope.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=481,
)

_INVOKEENVELOPE = _descriptor.Descriptor(
  name='InvokeEnvelope',
  full_name='daprclient.InvokeEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='method', full_name='daprclient.InvokeEnvelope.method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='daprclient.InvokeEnvelope.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='daprclient.InvokeEnvelope.metadata', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INVOKEENVELOPE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=792,
)


_GETTOPICSUBSCRIPTIONSENVELOPE = _descriptor.Descriptor(
  name='GetTopicSubscriptionsEnvelope',
  full_name='daprclient.GetTopicSubscriptionsEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topics', full_name='daprclient.GetTopicSubscriptionsEnvelope.topics', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=794,
  serialized_end=841,
)


_GETBINDINGSSUBSCRIPTIONSENVELOPE = _descriptor.Descriptor(
  name='GetBindingsSubscriptionsEnvelope',
  full_name='daprclient.GetBindingsSubscriptionsEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bindings', full_name='daprclient.GetBindingsSubscriptionsEnvelope.bindings', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=843,
  serialized_end=895,
)


_STATE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='daprclient.State.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='daprclient.State.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='daprclient.State.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=481,
)

_STATE = _descriptor.Descriptor(
  name='State',
  full_name='daprclient.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='daprclient.State.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='daprclient.State.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='etag', full_name='daprclient.State.etag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='daprclient.State.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='daprclient.State.options', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STATE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=898,
  serialized_end=1112,
)


_STATEOPTIONS = _descriptor.Descriptor(
  name='StateOptions',
  full_name='daprclient.StateOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='concurrency', full_name='daprclient.StateOptions.concurrency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consistency', full_name='daprclient.StateOptions.consistency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retryPolicy', full_name='daprclient.StateOptions.retryPolicy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1114,
  serialized_end=1216,
)


_RETRYPOLICY = _descriptor.Descriptor(
  name='RetryPolicy',
  full_name='daprclient.RetryPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='threshold', full_name='daprclient.RetryPolicy.threshold', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='daprclient.RetryPolicy.pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='daprclient.RetryPolicy.interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1218,
  serialized_end=1312,
)

_CLOUDEVENTENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_BINDINGEVENTENVELOPE_METADATAENTRY.containing_type = _BINDINGEVENTENVELOPE
_BINDINGEVENTENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_BINDINGEVENTENVELOPE.fields_by_name['metadata'].message_type = _BINDINGEVENTENVELOPE_METADATAENTRY
_BINDINGRESPONSEENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_BINDINGRESPONSEENVELOPE.fields_by_name['state'].message_type = _STATE
_INVOKEENVELOPE_METADATAENTRY.containing_type = _INVOKEENVELOPE
_INVOKEENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INVOKEENVELOPE.fields_by_name['metadata'].message_type = _INVOKEENVELOPE_METADATAENTRY
_STATE_METADATAENTRY.containing_type = _STATE
_STATE.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STATE.fields_by_name['metadata'].message_type = _STATE_METADATAENTRY
_STATE.fields_by_name['options'].message_type = _STATEOPTIONS
_STATEOPTIONS.fields_by_name['retryPolicy'].message_type = _RETRYPOLICY
_RETRYPOLICY.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['CloudEventEnvelope'] = _CLOUDEVENTENVELOPE
DESCRIPTOR.message_types_by_name['BindingEventEnvelope'] = _BINDINGEVENTENVELOPE
DESCRIPTOR.message_types_by_name['BindingResponseEnvelope'] = _BINDINGRESPONSEENVELOPE
DESCRIPTOR.message_types_by_name['InvokeEnvelope'] = _INVOKEENVELOPE
DESCRIPTOR.message_types_by_name['GetTopicSubscriptionsEnvelope'] = _GETTOPICSUBSCRIPTIONSENVELOPE
DESCRIPTOR.message_types_by_name['GetBindingsSubscriptionsEnvelope'] = _GETBINDINGSSUBSCRIPTIONSENVELOPE
DESCRIPTOR.message_types_by_name['State'] = _STATE
DESCRIPTOR.message_types_by_name['StateOptions'] = _STATEOPTIONS
DESCRIPTOR.message_types_by_name['RetryPolicy'] = _RETRYPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CloudEventEnvelope = _reflection.GeneratedProtocolMessageType('CloudEventEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDEVENTENVELOPE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.CloudEventEnvelope)
  })
_sym_db.RegisterMessage(CloudEventEnvelope)

BindingEventEnvelope = _reflection.GeneratedProtocolMessageType('BindingEventEnvelope', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _BINDINGEVENTENVELOPE_METADATAENTRY,
    '__module__' : 'daprclient.daprclient_pb2'
    # @@protoc_insertion_point(class_scope:daprclient.BindingEventEnvelope.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _BINDINGEVENTENVELOPE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.BindingEventEnvelope)
  })
_sym_db.RegisterMessage(BindingEventEnvelope)
_sym_db.RegisterMessage(BindingEventEnvelope.MetadataEntry)

BindingResponseEnvelope = _reflection.GeneratedProtocolMessageType('BindingResponseEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _BINDINGRESPONSEENVELOPE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.BindingResponseEnvelope)
  })
_sym_db.RegisterMessage(BindingResponseEnvelope)

InvokeEnvelope = _reflection.GeneratedProtocolMessageType('InvokeEnvelope', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVOKEENVELOPE_METADATAENTRY,
    '__module__' : 'daprclient.daprclient_pb2'
    # @@protoc_insertion_point(class_scope:daprclient.InvokeEnvelope.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _INVOKEENVELOPE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.InvokeEnvelope)
  })
_sym_db.RegisterMessage(InvokeEnvelope)
_sym_db.RegisterMessage(InvokeEnvelope.MetadataEntry)

GetTopicSubscriptionsEnvelope = _reflection.GeneratedProtocolMessageType('GetTopicSubscriptionsEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _GETTOPICSUBSCRIPTIONSENVELOPE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.GetTopicSubscriptionsEnvelope)
  })
_sym_db.RegisterMessage(GetTopicSubscriptionsEnvelope)

GetBindingsSubscriptionsEnvelope = _reflection.GeneratedProtocolMessageType('GetBindingsSubscriptionsEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _GETBINDINGSSUBSCRIPTIONSENVELOPE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.GetBindingsSubscriptionsEnvelope)
  })
_sym_db.RegisterMessage(GetBindingsSubscriptionsEnvelope)

State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATE_METADATAENTRY,
    '__module__' : 'daprclient.daprclient_pb2'
    # @@protoc_insertion_point(class_scope:daprclient.State.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _STATE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.State)
  })
_sym_db.RegisterMessage(State)
_sym_db.RegisterMessage(State.MetadataEntry)

StateOptions = _reflection.GeneratedProtocolMessageType('StateOptions', (_message.Message,), {
  'DESCRIPTOR' : _STATEOPTIONS,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.StateOptions)
  })
_sym_db.RegisterMessage(StateOptions)

RetryPolicy = _reflection.GeneratedProtocolMessageType('RetryPolicy', (_message.Message,), {
  'DESCRIPTOR' : _RETRYPOLICY,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.RetryPolicy)
  })
_sym_db.RegisterMessage(RetryPolicy)


DESCRIPTOR._options = None
_BINDINGEVENTENVELOPE_METADATAENTRY._options = None
_INVOKEENVELOPE_METADATAENTRY._options = None
_STATE_METADATAENTRY._options = None

_DAPRCLIENT = _descriptor.ServiceDescriptor(
  name='DaprClient',
  full_name='daprclient.DaprClient',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1315,
  serialized_end=1750,
  methods=[
  _descriptor.MethodDescriptor(
    name='OnInvoke',
    full_name='daprclient.DaprClient.OnInvoke',
    index=0,
    containing_service=None,
    input_type=_INVOKEENVELOPE,
    output_type=google_dot_protobuf_dot_any__pb2._ANY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTopicSubscriptions',
    full_name='daprclient.DaprClient.GetTopicSubscriptions',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETTOPICSUBSCRIPTIONSENVELOPE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBindingsSubscriptions',
    full_name='daprclient.DaprClient.GetBindingsSubscriptions',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETBINDINGSSUBSCRIPTIONSENVELOPE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OnBindingEvent',
    full_name='daprclient.DaprClient.OnBindingEvent',
    index=3,
    containing_service=None,
    input_type=_BINDINGEVENTENVELOPE,
    output_type=_BINDINGRESPONSEENVELOPE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OnTopicEvent',
    full_name='daprclient.DaprClient.OnTopicEvent',
    index=4,
    containing_service=None,
    input_type=_CLOUDEVENTENVELOPE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DAPRCLIENT)

DESCRIPTOR.services_by_name['DaprClient'] = _DAPRCLIENT

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from dapr import dapr_pb2 as dapr_dot_dapr__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class DaprStub(object):
  """Dapr definitions
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.PublishEvent = channel.unary_unary(
        '/dapr.Dapr/PublishEvent',
        request_serializer=dapr_dot_dapr__pb2.PublishEventEnvelope.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.InvokeService = channel.unary_unary(
        '/dapr.Dapr/InvokeService',
        request_serializer=dapr_dot_dapr__pb2.InvokeServiceEnvelope.SerializeToString,
        response_deserializer=dapr_dot_dapr__pb2.InvokeServiceResponseEnvelope.FromString,
        )
    self.InvokeBinding = channel.unary_unary(
        '/dapr.Dapr/InvokeBinding',
        request_serializer=dapr_dot_dapr__pb2.InvokeBindingEnvelope.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.GetState = channel.unary_unary(
        '/dapr.Dapr/GetState',
        request_serializer=dapr_dot_dapr__pb2.GetStateEnvelope.SerializeToString,
        response_deserializer=dapr_dot_dapr__pb2.GetStateResponseEnvelope.FromString,
        )
    self.SaveState = channel.unary_unary(
        '/dapr.Dapr/SaveState',
        request_serializer=dapr_dot_dapr__pb2.SaveStateEnvelope.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
    self.DeleteState = channel.unary_unary(
        '/dapr.Dapr/DeleteState',
        request_serializer=dapr_dot_dapr__pb2.DeleteStateEnvelope.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class DaprServicer(object):
  """Dapr definitions
  """

  def PublishEvent(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InvokeService(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def InvokeBinding(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetState(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SaveState(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteState(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DaprServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'PublishEvent': grpc.unary_unary_rpc_method_handler(
          servicer.PublishEvent,
          request_deserializer=dapr_dot_dapr__pb2.PublishEventEnvelope.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'InvokeService': grpc.unary_unary_rpc_method_handler(
          servicer.InvokeService,
          request_deserializer=dapr_dot_dapr__pb2.InvokeServiceEnvelope.FromString,
          response_serializer=dapr_dot_dapr__pb2.InvokeServiceResponseEnvelope.SerializeToString,
      ),
      'InvokeBinding': grpc.unary_unary_rpc_method_handler(
          servicer.InvokeBinding,
          request_deserializer=dapr_dot_dapr__pb2.InvokeBindingEnvelope.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'GetState': grpc.unary_unary_rpc_method_handler(
          servicer.GetState,
          request_deserializer=dapr_dot_dapr__pb2.GetStateEnvelope.FromString,
          response_serializer=dapr_dot_dapr__pb2.GetStateResponseEnvelope.SerializeToString,
      ),
      'SaveState': grpc.unary_unary_rpc_method_handler(
          servicer.SaveState,
          request_deserializer=dapr_dot_dapr__pb2.SaveStateEnvelope.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
      'DeleteState': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteState,
          request_deserializer=dapr_dot_dapr__pb2.DeleteStateEnvelope.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'dapr.Dapr', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from daprclient import daprclient_pb2 as daprclient_dot_daprclient__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class DaprClientStub(object):
  """User Code definitions
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.OnInvoke = channel.unary_unary(
        '/daprclient.DaprClient/OnInvoke',
        request_serializer=daprclient_dot_daprclient__pb2.InvokeEnvelope.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_any__pb2.Any.FromString,
        )
    self.GetTopicSubscriptions = channel.unary_unary(
        '/daprclient.DaprClient/GetTopicSubscriptions',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=daprclient_dot_daprclient__pb2.GetTopicSubscriptionsEnvelope.FromString,
        )
    self.GetBindingsSubscriptions = channel.unary_unary(
        '/daprclient.DaprClient/GetBindingsSubscriptions',
        request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        response_deserializer=daprclient_dot_daprclient__pb2.GetBindingsSubscriptionsEnvelope.FromString,
        )
    self.OnBindingEvent = channel.unary_unary(
        '/daprclient.DaprClient/OnBindingEvent',
        request_serializer=daprclient_dot_daprclient__pb2.BindingEventEnvelope.SerializeToString,
        response_deserializer=daprclient_dot_daprclient__pb2.BindingResponseEnvelope.FromString,
        )
    self.OnTopicEvent = channel.unary_unary(
        '/daprclient.DaprClient/OnTopicEvent',
        request_serializer=daprclient_dot_daprclient__pb2.CloudEventEnvelope.SerializeToString,
        response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )


class DaprClientServicer(object):
  """User Code definitions
  """

  def OnInvoke(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetTopicSubscriptions(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetBindingsSubscriptions(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OnBindingEvent(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OnTopicEvent(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DaprClientServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'OnInvoke': grpc.unary_unary_rpc_method_handler(
          servicer.OnInvoke,
          request_deserializer=daprclient_dot_daprclient__pb2.InvokeEnvelope.FromString,
          response_serializer=google_dot_protobuf_dot_any__pb2.Any.SerializeToString,
      ),
      'GetTopicSubscriptions': grpc.unary_unary_rpc_method_handler(
          servicer.GetTopicSubscriptions,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=daprclient_dot_daprclient__pb2.GetTopicSubscriptionsEnvelope.SerializeToString,
      ),
      'GetBindingsSubscriptions': grpc.unary_unary_rpc_method_handler(
          servicer.GetBindingsSubscriptions,
          request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
          response_serializer=daprclient_dot_daprclient__pb2.GetBindingsSubscriptionsEnvelope.SerializeToString,
      ),
      'OnBindingEvent': grpc.unary_unary_rpc_method_handler(
          servicer.OnBindingEvent,
          request_deserializer=daprclient_dot_daprclient__pb2.BindingEventEnvelope.FromString,
          response_serializer=daprclient_dot_daprclient__pb2.BindingResponseEnvelope.SerializeToString,
      ),
      'OnTopicEvent': grpc.unary_unary_rpc_method_handler(
          servicer.OnTopicEvent,
          request_deserializer=daprclient_dot_daprclient__pb2.CloudEventEnvelope.FromString,
          response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'daprclient.DaprClient', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



import setuptools
with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="dapr-client",
    version="0.1.0.b1",
    author="dapr.io",
    author_email="pypidapr@microsoft.com",
    description="Dapr client sdk using gRPC.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://dapr.io/",
    packages=setuptools.find_packages(),
    install_requires=[
          'protobuf',
          'grpcio'
      ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
